package com.persagy.server.service


import com.persagy.server.models.EquipCompon
import com.persagy.server.models.mappers.REquipComponMapper
import com.persagy.server.models.requests.RSQueryResponse
import com.persagy.service.models.enums.SResponseType
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.stereotype.Service

/**
 * 查询当前设备类型下允许的所有部件类型，设备下的部件对应数量 服务
 *
 * @author 张维新
 */
@Service
open class REquipComponService {

    /** 实例化 mapper 对象 */
    @Autowired
    lateinit var mapper: REquipComponMapper

    /**
     * 查询当前设备类型下允许的所有部件类型，设备下的部件对应数量
     *
     * @param   id          设备id
     * @param   category    分类
     */
    open fun getEquipCompon(id:String, category: String): RSQueryResponse<EquipCompon> {
        return try {
            val equipComponList = mapper.getEquipCompon(id, category)
            val rsQueryResponse = RSQueryResponse<EquipCompon>()
            rsQueryResponse.content = equipComponList
            rsQueryResponse.total = equipComponList.size.toLong()
            rsQueryResponse
        } catch (e: Exception) {
            e.printStackTrace()
            RSQueryResponse(SResponseType.failure, e.message!!)
        }
    } // Function getEquipCompon()

} // Class EquipComponService